@@ -1,3 +1,7 @@
+# Copyright (C) 2003-2006 Kouichirou Eto, All rights reserved.
+# This is free software with ABSOLUTELY NO WARRANTY.
+# You can redistribute it and/or modify it under the terms of the GNU GPL 2.
+
 $LOAD_PATH << '..' unless $LOAD_PATH.include? '..'
 require 'qwik/config'
 require 'qwik/util-tail'
@@ -35,7 +39,7 @@ module Qwik
       end
     end
 
-    def tail_f(file)
+    def nu_tail_f(file)
       Thread.new {
 	tail = Tail.new(file, 0, Tail::TAIL_END)
 	tail.gets { |line|
@@ -44,7 +48,7 @@ module Qwik
       }
     end
 
-    def nutail_f(file)
+    def tail_f(file)
       Thread.new {
 	open(file) {|f|
 	  f.seek(IO::SEEK_END, 0)
